@@ -5,10 +5,10 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/alecthomas/assert"
 	"github.com/scaleway/scaleway-cli/v2/commands"
 	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/core/human"
+	"github.com/stretchr/testify/assert"
 )
 
 func Test_Alias(t *testing.T) {
@@ -85,6 +85,7 @@ func Test_Alias(t *testing.T) {
 				if strings.Contains(resString, "instance") {
 					return errors.New("alias list should not contain instance")
 				}
+
 				return nil
 			},
 		),
