@@ -13,7 +13,7 @@ import (
 )
 
 func Test_ImageCreate(t *testing.T) {
-	t.Run("Create simple image", core.Test(&core.TestConfig{
+	t.Run("Simple", core.Test(&core.TestConfig{
 		BeforeFunc: core.BeforeFuncCombine(
 			core.ExecStoreBeforeCmd(
 				"Server",
@@ -68,7 +68,7 @@ func Test_ImageCreate(t *testing.T) {
 }
 
 func Test_ImageDelete(t *testing.T) {
-	t.Run("simple", core.Test(&core.TestConfig{
+	t.Run("Simple", core.Test(&core.TestConfig{
 		BeforeFunc: createImage("Image"),
 		Commands:   instance.GetCommands(),
 		Cmd:        "scw instance image delete {{ .Image.Image.ID }} with-snapshots=true",
@@ -171,7 +171,10 @@ func Test_ImageList(t *testing.T) {
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(0),
 		),
-		AfterFunc: deleteImage("Image"),
+		AfterFunc: core.AfterFuncCombine(
+			deleteImage("Image"),
+			deleteServer("Server"),
+		),
 	}))
 
 	t.Run("With SBS root volume", core.Test(&core.TestConfig{
@@ -185,7 +188,10 @@ func Test_ImageList(t *testing.T) {
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(0),
 		),
-		AfterFunc: deleteImage("ImageSBSRoot"),
+		AfterFunc: core.AfterFuncCombine(
+			deleteImage("ImageSBSRoot"),
+			deleteServer("Server"),
+		),
 	}))
 
 	t.Run("With SBS additional volumes", core.Test(&core.TestConfig{
@@ -199,7 +205,10 @@ func Test_ImageList(t *testing.T) {
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(0),
 		),
-		AfterFunc: deleteImage("ImageSBSAdditional"),
+		AfterFunc: core.AfterFuncCombine(
+			deleteImage("ImageSBSAdditional"),
+			deleteServer("Server"),
+		),
 	}))
 }
 
