@@ -6,6 +6,7 @@ import (
 	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/instance/v1"
 	"github.com/scaleway/scaleway-cli/v2/internal/namespaces/vpc/v2"
+	"github.com/scaleway/scaleway-cli/v2/internal/testhelpers"
 )
 
 func Test_ListNICs(t *testing.T) {
@@ -15,7 +16,7 @@ func Test_ListNICs(t *testing.T) {
 	t.Run("Simple", core.Test(&core.TestConfig{
 		Commands: cmds,
 		BeforeFunc: core.BeforeFuncCombine(
-			createPN(),
+			testhelpers.CreatePN(),
 			createServer("Server"),
 			createNIC(),
 		),
@@ -23,6 +24,10 @@ func Test_ListNICs(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 		),
+		AfterFunc: core.AfterFuncCombine(
+			deleteServer("Server"),
+			testhelpers.DeletePN(),
+		),
 	}))
 }
 
@@ -33,7 +38,7 @@ func Test_GetPrivateNIC(t *testing.T) {
 	t.Run("Get from ID", core.Test(&core.TestConfig{
 		Commands: cmds,
 		BeforeFunc: core.BeforeFuncCombine(
-			createPN(),
+			testhelpers.CreatePN(),
 			createServer("Server"),
 			createNIC(),
 		),
@@ -41,12 +46,16 @@ func Test_GetPrivateNIC(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 		),
+		AfterFunc: core.AfterFuncCombine(
+			deleteServer("Server"),
+			testhelpers.DeletePN(),
+		),
 	}))
 
 	t.Run("Get from MAC address", core.Test(&core.TestConfig{
 		Commands: cmds,
 		BeforeFunc: core.BeforeFuncCombine(
-			createPN(),
+			testhelpers.CreatePN(),
 			createServer("Server"),
 			createNIC(),
 		),
@@ -54,5 +63,9 @@ func Test_GetPrivateNIC(t *testing.T) {
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 		),
+		AfterFunc: core.AfterFuncCombine(
+			deleteServer("Server"),
+			testhelpers.DeletePN(),
+		),
 	}))
 }
