@@ -31,7 +31,7 @@ var (
 	}
 )
 
-func iotDeviceCreateResponsedMarshalerFunc(i any, opt *human.MarshalOpt) (string, error) {
+func iotDeviceCreateResponseMarshalerFunc(i any, opt *human.MarshalOpt) (string, error) {
 	type tmp iot.CreateDeviceResponse
 	deviceCreateResponse := tmp(*i.(*iot.CreateDeviceResponse))
 
