@@ -20,7 +20,12 @@ var jobRunStateMarshalSpecs = human.EnumMarshalSpecs{
 func GetCommands() *core.Commands {
 	cmds := GetGeneratedCommands()
 
-	human.RegisterMarshalerFunc(jobs.JobRunState(""), human.EnumMarshalFunc(jobRunStateMarshalSpecs))
+	cmds.MustFind("jobs").Groups = []string{"serverless"}
+
+	human.RegisterMarshalerFunc(
+		jobs.JobRunState(""),
+		human.EnumMarshalFunc(jobRunStateMarshalSpecs),
+	)
 
 	cmds.Merge(core.NewCommands(
 		jobsRunWait(),
