@@ -9,7 +9,12 @@ import (
 func GetCommands() *core.Commands {
 	cmds := GetGeneratedCommands()
 
-	human.RegisterMarshalerFunc(mnq.SnsInfoStatus(""), human.EnumMarshalFunc(mnqSqsInfoStatusMarshalSpecs))
+	cmds.MustFind("mnq").Groups = []string{"integration"}
+
+	human.RegisterMarshalerFunc(
+		mnq.SnsInfoStatus(""),
+		human.EnumMarshalFunc(mnqSqsInfoStatusMarshalSpecs),
+	)
 
 	cmds.MustFind("mnq", "nats", "get-account").Override(mnqNatsGetAccountBuilder)
 	cmds.MustFind("mnq", "nats", "list-credentials").Override(mnqNatsListCredentialsBuilder)
