@@ -14,7 +14,7 @@ import (
 )
 
 const (
-	baseCommand = "scw redis cluster create --wait name=%s version=7.0.5 node-type=RED1-micro user-name=admin password=P@sSw0Rd "
+	baseCommand = "scw redis cluster create --wait name=%s version=7.2.11 node-type=RED1-micro user-name=admin password=P@sSw0Rd "
 	serviceIPsA = "172.16.4.1/22"
 	serviceIPsB = "10.16.4.1/22"
 	metaNamePNA = "PrivateNetworkA"
@@ -39,8 +39,10 @@ func Test_Endpoints(t *testing.T) {
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
-				endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
-				checkEndpoints(t, endpoints, 1, 0, 0)
+				if ctx.Result != nil {
+					endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
+					checkEndpoints(t, endpoints, 1, 0, 0)
+				}
 			},
 		),
 		AfterFunc: deleteCluster(),
@@ -64,8 +66,10 @@ func Test_Endpoints(t *testing.T) {
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
-				endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
-				checkEndpoints(t, endpoints, 0, 1, 0)
+				if ctx.Result != nil {
+					endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
+					checkEndpoints(t, endpoints, 0, 1, 0)
+				}
 			},
 		),
 		AfterFunc: core.AfterFuncCombine(
@@ -88,7 +92,7 @@ func Test_Endpoints(t *testing.T) {
 			),
 		),
 		Cmd: fmt.Sprintf(
-			"scw redis cluster create --wait name=%s version=7.0.5 node-type=RED1-micro user-name=admin password=P@sSw0Rd --wait "+
+			"scw redis cluster create --wait name=%s version=7.2.11 node-type=RED1-micro user-name=admin password=P@sSw0Rd --wait "+
 				"endpoints.0.private-network.id={{ .%s.ID }} endpoints.0.private-network.service-ips.0=%s "+
 				"endpoints.1.private-network.id={{ .%s.ID }} endpoints.1.private-network.service-ips.0=%s",
 			"2-static-priv-endpoints",
@@ -101,8 +105,10 @@ func Test_Endpoints(t *testing.T) {
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
-				endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
-				checkEndpoints(t, endpoints, 0, 2, 0)
+				if ctx.Result != nil {
+					endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
+					checkEndpoints(t, endpoints, 0, 2, 0)
+				}
 			},
 		),
 		AfterFunc: core.AfterFuncCombine(
@@ -136,8 +142,10 @@ func Test_IpamConfig(t *testing.T) {
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
-				endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
-				checkEndpoints(t, endpoints, 0, 0, 1)
+				if ctx.Result != nil {
+					endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
+					checkEndpoints(t, endpoints, 0, 0, 1)
+				}
 			},
 		),
 		AfterFunc: core.AfterFuncCombine(
@@ -167,8 +175,10 @@ func Test_IpamConfig(t *testing.T) {
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
-				endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
-				checkEndpoints(t, endpoints, 0, 0, 2)
+				if ctx.Result != nil {
+					endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
+					checkEndpoints(t, endpoints, 0, 0, 2)
+				}
 			},
 		),
 		AfterFunc: core.AfterFuncCombine(
@@ -199,8 +209,10 @@ func Test_IpamConfig(t *testing.T) {
 			core.TestCheckGolden(),
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
-				endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
-				checkEndpoints(t, endpoints, 0, 1, 1)
+				if ctx.Result != nil {
+					endpoints := ctx.Result.(*redisSDK.Cluster).Endpoints
+					checkEndpoints(t, endpoints, 0, 1, 1)
+				}
 			},
 		),
 		AfterFunc: core.AfterFuncCombine(
