@@ -35,7 +35,7 @@ You will need to have the chosen binary installed on your system and in your PAT
 	}
 }
 
-func registryLogoutRun(ctx context.Context, argsI interface{}) (i interface{}, e error) {
+func registryLogoutRun(ctx context.Context, argsI any) (i any, e error) {
 	args := argsI.(*registryLogoutArgs)
 
 	region := args.Region.String()
