@@ -3,12 +3,15 @@ package registry
 import (
 	"context"
 	"fmt"
+	"reflect"
+	"time"
 
 	"github.com/fatih/color"
 	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/core/human"
 	"github.com/scaleway/scaleway-sdk-go/api/registry/v1"
 	"github.com/scaleway/scaleway-sdk-go/logger"
+	"github.com/scaleway/scaleway-sdk-go/scw"
 )
 
 //
@@ -25,7 +28,7 @@ var (
 	}
 )
 
-type customTag struct {
+type CustomTag struct {
 	registry.Tag
 	FullName string
 }
@@ -59,7 +62,7 @@ func tagGetBuilder(c *core.Command) *core.Command {
 			return getTagResp, nil
 		}
 
-		res := customTag{
+		res := CustomTag{
 			Tag:      *tag,
 			FullName: fmt.Sprintf("%s/%s:%s", namespace.Endpoint, image.Name, tag.Name),
 		}
@@ -112,9 +115,9 @@ func tagListBuilder(c *core.Command) *core.Command {
 			return listTagResp, err
 		}
 
-		var customRes []customTag
+		var customRes []CustomTag
 		for _, tag := range listTagResp.([]*registry.Tag) {
-			customRes = append(customRes, customTag{
+			customRes = append(customRes, CustomTag{
 				Tag: *tag,
 				FullName: fmt.Sprintf("%s/%s:%s",
 					namespace.Endpoint,
@@ -129,3 +132,40 @@ func tagListBuilder(c *core.Command) *core.Command {
 
 	return c
 }
+
+type customTagDeleteArgs struct {
+	registry.DeleteTagRequest
+	Timeout *string
+}
+
+func tagDeleteBuilder(c *core.Command) *core.Command {
+	c.ArgsType = reflect.TypeOf(customTagDeleteArgs{})
+	c.ArgSpecs.AddBefore("force", &core.ArgSpec{
+		Name:       "timeout",
+		Short:      "Maximum time to handle the request",
+		Required:   false,
+		Positional: false,
+	})
+
+	c.Run = func(ctx context.Context, argsI any) (any, error) {
+		client := core.ExtractClient(ctx)
+		api := registry.NewAPI(client)
+		args := argsI.(*customTagDeleteArgs)
+
+		if args.Timeout == nil {
+			return api.DeleteTag(&args.DeleteTagRequest, scw.WithContext(ctx))
+		}
+
+		timeout, err := time.ParseDuration(*args.Timeout)
+		if err != nil {
+			return nil, err
+		}
+
+		ctxWithTimeout, cancel := context.WithTimeout(ctx, timeout)
+		defer cancel()
+
+		return api.DeleteTag(&args.DeleteTagRequest, scw.WithContext(ctxWithTimeout))
+	}
+
+	return c
+}
