@@ -7,7 +7,7 @@ import (
 	"github.com/scaleway/scaleway-cli/v2/core/human"
 	applesilicon "github.com/scaleway/scaleway-sdk-go/api/applesilicon/v1alpha1"
 	"github.com/scaleway/scaleway-sdk-go/api/baremetal/v1"
-	inference "github.com/scaleway/scaleway-sdk-go/api/inference/v1beta1"
+	inference "github.com/scaleway/scaleway-sdk-go/api/inference/v1"
 	"github.com/scaleway/scaleway-sdk-go/api/instance/v1"
 	"github.com/scaleway/scaleway-sdk-go/api/ipam/v1"
 	"github.com/scaleway/scaleway-sdk-go/api/k8s/v1"
@@ -71,57 +71,57 @@ func privateNetworkGetBuilder(c *core.Command) *core.Command {
 		g.Go(func() (err error) {
 			instanceServers, err = listCustomInstanceServers(groupCtx, client, pn)
 
-			return
+			return err
 		})
 		g.Go(func() (err error) {
 			baremetalServers, err = listCustomBaremetalServers(groupCtx, client, pn)
 
-			return
+			return err
 		})
 		g.Go(func() (err error) {
 			k8sClusters, err = listCustomK8sClusters(groupCtx, client, pn)
 
-			return
+			return err
 		})
 		g.Go(func() (err error) {
 			lbs, err = listCustomLBs(groupCtx, client, pn)
 
-			return
+			return err
 		})
 		g.Go(func() (err error) {
 			rdbs, err = listCustomRdbs(groupCtx, client, pn)
 
-			return
+			return err
 		})
 		g.Go(func() (err error) {
 			redisClusters, err = listCustomRedisClusters(groupCtx, client, pn)
 
-			return
+			return err
 		})
 		g.Go(func() (err error) {
 			gateways, err = listCustomGateways(groupCtx, client, pn)
 
-			return
+			return err
 		})
 		g.Go(func() (err error) {
 			appleSiliconServers, err = listCustomAppleSiliconServers(groupCtx, client, pn)
 
-			return
+			return err
 		})
 		g.Go(func() (err error) {
 			mongoDBs, err = listCustomMongoDBs(groupCtx, client, pn)
 
-			return
+			return err
 		})
 		g.Go(func() (err error) {
 			ipamIPs, err = listCustomIPAMIPs(groupCtx, client, pn)
 
-			return
+			return err
 		})
 		g.Go(func() (err error) {
 			inferenceDeployments, err = listCustomInferenceDeployments(groupCtx, client, pn)
 
-			return
+			return err
 		})
 
 		if err = g.Wait(); err != nil {
@@ -715,3 +715,16 @@ func intersectZones(regionZones, apiZones []scw.Zone) []scw.Zone {
 
 	return intersect
 }
+
+func privateNetworkDeleteBuilder(c *core.Command) *core.Command {
+	c.Run = func(ctx context.Context, args any) (i any, e error) {
+		request := args.(*vpc.DeletePrivateNetworkRequest)
+
+		client := core.ExtractClient(ctx)
+		api := vpc.NewAPI(client)
+
+		return api.TryDeletingPrivateNetwork(request, 5, scw.WithContext(ctx))
+	}
+
+	return c
+}
