@@ -9,7 +9,7 @@ import (
 
 func vpcgwGatewayTypeListBuilder(c *core.Command) *core.Command {
 	c.AddInterceptors(
-		func(ctx context.Context, argsI interface{}, runner core.CommandRunner) (interface{}, error) {
+		func(ctx context.Context, argsI any, runner core.CommandRunner) (any, error) {
 			res, err := runner(ctx, argsI)
 			if err != nil {
 				return nil, err
